"use strict";exports.__esModule=true;exports.default=cache;exports.usedBabelCacheFiles=void 0;var _fs=_interopRequireDefault(require("fs"));var _os=_interopRequireDefault(require("os"));var _path=_interopRequireDefault(require("path"));var _crypto=_interopRequireDefault(require("crypto"));var _mkdirp=_interopRequireDefault(require("mkdirp"));var _util=require("util");var _transform=_interopRequireDefault(require("./transform"));function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}/**
 * Filesystem Cache
 *
 * Given a file and a transform function, cache the result into files
 * or retrieve the previously cached files if the given file is already known.
 *
 * @see https://github.com/babel/babel-loader/issues/34
 * @see https://github.com/babel/babel-loader/pull/41
 */ // Lazily instantiated when needed
let defaultCacheDirectory=null;const readFile=(0,_util.promisify)(_fs.default.readFile);const writeFile=(0,_util.promisify)(_fs.default.writeFile);const mkdirp=(0,_util.promisify)(_mkdirp.default);const usedBabelCacheFiles=new Set();/**
 * Read the contents from the compressed file.
 *
 * @async
 * @params {String} filename
 */exports.usedBabelCacheFiles=usedBabelCacheFiles;async function read(filename){const data=await readFile(filename);const content=data;usedBabelCacheFiles.add(filename);return JSON.parse(content.toString());};/**
 * Write contents into a compressed file.
 */async function write(filename,result){const content=JSON.stringify(result);usedBabelCacheFiles.add(filename);return await writeFile(filename,content);};/**
 * Build the filename for the cached file
 */function filename(source,identifier,options){const hash=_crypto.default.createHash("md4");const contents=JSON.stringify({source,options,identifier});hash.update(contents);return hash.digest("hex")+".json";};/**
 * Handle the cache
 */async function handleCache(directory,params){const{source,options={},cacheIdentifier,cacheDirectory}=params;const file=_path.default.join(directory,filename(source,cacheIdentifier,options));try{// No errors mean that the file was previously cached
// we just need to return it
return await read(file);}catch(err){}const fallback=typeof cacheDirectory!=="string"&&directory!==_os.default.tmpdir();// Make sure the directory exists.
try{await mkdirp(directory);}catch(err){if(fallback){return handleCache(_os.default.tmpdir(),params);}throw err;}// Otherwise just transform the file
// return it to the user asap and write it in cache
const result=await(0,_transform.default)(source,options);try{await write(file,result);}catch(err){if(fallback){// Fallback to tmpdir if node_modules folder not writable
return handleCache(_os.default.tmpdir(),params);}throw err;}return result;};/**
 * Retrieve file from cache, or create a new one for future reads
 *
 * @async
 * @param  {Object}   params
 * @param  {String}   params.directory  Directory to store cached files
 * @param  {String}   params.identifier Unique identifier to bust cache
 * @param  {String}   params.source   Original contents of the file to be cached
 * @param  {Object}   params.options  Options to be given to the transform fn
 * @param  {Function} params.transform  Function that will transform the
 *                                      original file and whose result will be
 *                                      cached
 *
 * @example
 *
 *   cache({
 *     directory: '.tmp/cache',
 *     identifier: 'babel-loader-cachefile',
 *     source: *source code from file*,
 *     options: {
 *       experimental: true,
 *       runtime: true
 *     },
 *     transform: function(source, options) {
 *       var content = *do what you need with the source*
 *       return content;
 *     }
 *   }, function(err, result) {
 *
 *   });
 */async function cache(params){let directory;if(typeof params.cacheDirectory==="string"){directory=params.cacheDirectory;}else{directory=defaultCacheDirectory;}return await handleCache(directory,params);};